@@ -48,8 +48,6 @@ class Imbalanced_Dataset:
         lb_imb_ratio,
         ulb_imb_ratio,
         imb_type,
-        onehot=False,
-        dset=True,
         seed=0,
     ):
         """
@@ -61,15 +59,10 @@ class Imbalanced_Dataset:
             lb_img_ratio: imbalance ratio of labeled data.
             ulb_imb_ratio: imbalance ratio of unlabeled data.
             imb_type: type of imbalance data.
-            onehot: If True, the target is converted into onehot vector.
-            dset: If True, return BasicDataset else return raw data.
             seed: Get deterministic results of labeled and unlabeld data.
 
         Returns:
-        if dset = True:
-            BasicDataset (for labeled data), BasicDataset (for unlabeld data)
-        else:
-            labeled (data, targets), unlabeled (data, None)
+            labeled (data, targets), unlabeled (data, targets)
         """
         data, targets = self.get_data()
 
@@ -94,10 +87,4 @@ class Imbalanced_Dataset:
 
         np.random.set_state(state)
 
-        if dset:
-            lb_dset = ResampleDataset(lb_data, lb_targets, self.num_classes, self.train_transform, self.test_transform, onehot=onehot, seed=seed)
-            ulb_dset = BasicDataset(ulb_data, ulb_targets, self.num_classes, self.test_transform, is_ulb=True, onehot=onehot)
-
-            return lb_dset, ulb_dset
-        else:
-            return (lb_data, lb_targets), (ulb_data, None)
+        return (lb_data, lb_targets), (ulb_data, ulb_targets)
